@@ -33,7 +33,6 @@ class Context(object):
     libs_dir = None  # where Android libs are cached after build but
                      # before being placed in dists
     aars_dir = None
-    javaclass_dir = None
 
     ccache = None  # whether to use ccache
     cython = None  # the cython interpreter name
@@ -46,6 +45,8 @@ class Context(object):
 
     recipe_build_order = None  # Will hold the list of all built recipes
 
+    symlink_java_src = False # If True, will symlink instead of copying during build
+
     @property
     def packages_path(self):
         '''Where packages are downloaded before being unpacked'''
@@ -186,6 +187,8 @@ class Context(object):
             #                # for debug tests of p4a
             possible_dirs = glob.glob(expanduser(join(
                 '~', '.buildozer', 'android', 'platform', 'android-sdk-*')))
+            possible_dirs = [d for d in possible_dirs if not
+                             (d.endswith('.bz2') or d.endswith('.gz'))]
             if possible_dirs:
                 info('Found possible SDK dirs in buildozer dir: {}'.format(
                     ', '.join([d.split(os.sep)[-1] for d in possible_dirs])))
@@ -223,8 +226,15 @@ class Context(object):
             error('You probably want to build with --arch=armeabi-v7a instead')
             exit(1)
 
-        android = sh.Command(join(sdk_dir, 'tools', 'android'))
-        targets = android('list').stdout.decode('utf-8').split('\n')
+        if exists(join(sdk_dir, 'tools', 'bin', 'avdmanager')):
+            avdmanager = sh.Command(join(sdk_dir, 'tools', 'bin', 'avdmanager'))
+            targets = avdmanager('list', 'target').stdout.decode('utf-8').split('\n')
+        elif exists(join(sdk_dir, 'tools', 'android')):
+            android = sh.Command(join(sdk_dir, 'tools', 'android'))
+            targets = android('list').stdout.decode('utf-8').split('\n')
+        else:
+            error('Could not find `android` or `sdkmanager` binaries in '
+                  'Android SDK. Exiting.')
         apis = [s for s in targets if re.match(r'^ *API level: ', s)]
         apis = [re.findall(r'[0-9]+', s) for s in apis]
         apis = [int(s[0]) for s in apis if s]
@@ -527,6 +537,7 @@ def build_recipes(build_order, python_modules, ctx):
     bs = ctx.bootstrap
     info_notify("Recipe build order is {}".format(build_order))
     if python_modules:
+        python_modules = sorted(set(python_modules))
         info_notify(
             ('The requirements ({}) were not found as recipes, they will be '
              'installed with pip.').format(', '.join(python_modules)))
@@ -584,7 +595,7 @@ def build_recipes(build_order, python_modules, ctx):
 
 
 def run_pymodules_install(ctx, modules):
-    modules = filter(ctx.not_has_package, modules)
+    modules = list(filter(ctx.not_has_package, modules))
 
     if not modules:
         info('There are no Python modules to install, skipping')
@@ -838,6 +849,5 @@ def copylibs_function(soname, objs_paths, extra_link_dirs=[], env=None):
                             '\n\t'.join(needed_libs))
 
     print('Copying libraries')
-    cp = sh.cp.bake('-t', dest)
     for lib in sofiles:
-        shprint(cp, lib)
+        shprint(sh.cp, lib, dest)
