@@ -3,14 +3,15 @@ from os.path import dirname, join
 
 class CryptographyRecipe(CompiledComponentsPythonRecipe):
     name = 'cryptography'
-    version = '1.3.1'
-    url = 'https://pypi.python.org/packages/source/c/cryptography/cryptography-{version}.tar.gz'
-    depends = [('python2', 'python3crystax'), 'cffi', 'enum34', 'openssl', 'ipaddress', 'idna']
+    version = '1.4'
+    url = 'https://github.com/pyca/cryptography/archive/{version}.tar.gz'
+    depends = [('python2', 'python3crystax'), 'openssl', 'idna', 'pyasn1', 'six', 'setuptools', 'enum34', 'ipaddress', 'cffi']
     call_hostpython_via_targetpython = False
 
     def get_recipe_env(self, arch):
         env = super(CryptographyRecipe, self).get_recipe_env(arch)
-        openssl_dir = self.get_recipe('openssl', self.ctx).get_build_dir(arch.arch)
+        r = self.get_recipe('openssl', self.ctx)
+        openssl_dir = r.get_build_dir(arch.arch)
         env['PYTHON_ROOT'] = self.ctx.get_python_install_dir()
         env['CFLAGS'] += ' -I' + env['PYTHON_ROOT'] + '/include/python2.7' + \
                          ' -I' + join(openssl_dir, 'include')
@@ -19,7 +20,8 @@ class CryptographyRecipe(CompiledComponentsPythonRecipe):
         env['LDFLAGS'] += ' -L' + env['PYTHON_ROOT'] + '/lib' + \
                           ' -L' + openssl_dir + \
                           ' -lpython2.7' + \
-                          ' -lssl -lcrypto'
+                          ' -lssl' + r.version + \
+                          ' -lcrypto' + r.version
         return env
 
 recipe = CryptographyRecipe()
